
=====================
pydicom documentation
=====================

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Getting started

   tutorials/installation
   old/getting_started

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Documentation

   old/pydicom_user_guide
   old/ref_guide
   tutorials/index
   guides/index
   reference/index

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Examples

   auto_examples/index

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Additional Information

   tutorials/contributing
   faq/index
   release_notes/index


Getting Started
===============
If you're new to *pydicom* then start here:

* :doc:`Installation<tutorials/installation>` |
  :doc:`Introduction to pydicom<old/getting_started>` |
  :doc:`What Python types do I use for each VR<guides/element_value_types>`
* **Basics**: :doc:`Read, access, modify, write</tutorials/dataset_basics>`
* **Intermediate**:
  :doc:`Compressing Pixel Data </tutorials/pixel_data/compressing>` |
  :doc:`Waveform decoding and encoding </tutorials/waveforms>` |
  :doc:`DICOM File-sets and DICOMDIR</tutorials/filesets>`


:doc:`User Guide <old/pydicom_user_guide>`
==========================================

The main documentation. This contains an in-depth description of all
core elements of *pydicom* and how to use them.


:doc:`Examples <auto_examples/index>`
=====================================

A set of examples illustrating the use of the different core elements. It
complements the :doc:`User Guide <old/pydicom_user_guide>`.


:doc:`API Reference <reference/index>`
======================================

The API Reference provides technical documentation for the *pydicom* API's
functions, variables and classes.
